@@ -400,22 +400,32 @@ namespace
 {
 
     void set_memory_label_and_picker(GtkLabel* label, GsmColorButton* picker,
-                                     guint64 used, guint64 total, double percent)
+                                     guint64 used, guint64 cached, guint64 total, double percent)
     {
         char* used_text;
+        char* cached_text;
+        char* cached_label;
         char* total_text;
         char* text;
 
         used_text = g_format_size_full(used, G_FORMAT_SIZE_IEC_UNITS);
+        cached_text = g_format_size_full(cached, G_FORMAT_SIZE_IEC_UNITS);
         total_text = g_format_size_full(total, G_FORMAT_SIZE_IEC_UNITS);
         if (total == 0) {
             text = g_strdup(_("not available"));
         } else {
             // xgettext: 540MiB (53 %) of 1.0 GiB
             text = g_strdup_printf(_("%s (%.1f%%) of %s"), used_text, 100.0 * percent, total_text);
+
+            if (cached != 0) {
+                cached_label = g_strdup_printf(_("Cache %s"), cached_text);
+                text = g_strdup_printf("%s\n%s", text, cached_label);
+                g_free (cached_label);
+            }
         }
         gtk_label_set_text(label, text);
         g_free(used_text);
+        g_free(cached_text);
         g_free(total_text);
         g_free(text);
 
@@ -440,11 +450,11 @@ get_memory (LoadGraph *graph)
     mempercent  = (float)mem.user  / (float)mem.total;
     set_memory_label_and_picker(GTK_LABEL(graph->labels.memory),
                                 GSM_COLOR_BUTTON(graph->mem_color_picker),
-                                mem.user, mem.total, mempercent);
+                                mem.user, mem.cached, mem.total, mempercent);
 
     set_memory_label_and_picker(GTK_LABEL(graph->labels.swap),
                                 GSM_COLOR_BUTTON(graph->swap_color_picker),
-                                swap.used, swap.total, swappercent);
+                                swap.used, 0, swap.total, swappercent);
     
     gtk_widget_set_sensitive (GTK_WIDGET (graph->swap_color_picker), swap.total > 0);
     
@@ -597,7 +607,7 @@ get_net (LoadGraph *graph)
     char **ifnames;
     guint32 i;
     guint64 in = 0, out = 0;
-    GTimeVal time;
+    guint64 time;
     guint64 din, dout;
     gboolean first = true;
     ifnames = glibtop_get_netlist(&netlist);
@@ -631,12 +641,11 @@ get_net (LoadGraph *graph)
 
     g_strfreev(ifnames);
 
-    g_get_current_time (&time);
+    time = g_get_monotonic_time ();
 
-    if (in >= graph->net.last_in && out >= graph->net.last_out && graph->net.time.tv_sec != 0) {
+    if (in >= graph->net.last_in && out >= graph->net.last_out && graph->net.time != 0) {
         float dtime;
-        dtime = time.tv_sec - graph->net.time.tv_sec +
-                (double) (time.tv_usec - graph->net.time.tv_usec) / G_USEC_PER_SEC;
+        dtime = time - graph->net.time;
         din   = static_cast<guint64>((in  - graph->net.last_in)  / dtime);
         dout  = static_cast<guint64>((out - graph->net.last_out) / dtime);
     } else {
@@ -646,7 +655,7 @@ get_net (LoadGraph *graph)
         dout = 0;
     }
 
-    first = first && (graph->net.time.tv_sec==0);
+    first = first && (graph->net.time==0);
     graph->net.last_in  = in;
     graph->net.last_out = out;
     graph->net.time     = time;
